// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.register.provider.azure.subscriber;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.junit.jupiter.MockitoExtension;

import java.sql.Timestamp;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

@ExtendWith(MockitoExtension.class)
public class SubscriptionDocTest {

    private final static String id = "test-id";
    private final static String name = "test-action";
    private final static String description = "test-description";
    private final static String topic = "test-topic";
    private final static String pushEndpoint = "https://mycdn.com/img.png";
    private final static String createdBy = "test-creator";
    private final static Timestamp createdOnEpoch = new Timestamp(System.currentTimeMillis());
    private final static String notificationId = "test-notification-id";
    private final static String secretType = "HMAC";
    private final static String secretValue = "test-secret-value";
    private final static String dataPartitionId = "opendes";
    private final static String keyName = "key-name";
    private final static String keyVersion = "key-version";


    @Test
    public void shouldCreateActionDocWithAllArgsConstructorAndValidateSetters() {


        SubscriptionDoc doc = new SubscriptionDoc(id, name, description, topic, pushEndpoint, createdBy, createdOnEpoch, notificationId, secretType, secretValue, dataPartitionId, keyName, keyVersion);

        assertNotNull(doc);
        assertEquals(id, doc.getId());
        assertEquals(name, doc.getName());
        assertEquals(description, doc.getDescription());
        assertEquals(topic, doc.getTopic());
        assertEquals(pushEndpoint, doc.getPushEndpoint());
        assertEquals(createdBy, doc.getCreatedBy());
        assertEquals(createdOnEpoch, doc.getCreatedOnEpoch());
        assertEquals(notificationId, doc.getNotificationId());
        assertEquals(secretType, doc.getSecretType());
        assertEquals(secretValue, doc.getSecretValue());
        assertEquals(dataPartitionId, doc.getDataPartitionId());
        assertEquals(keyName, doc.getKeyName());
        assertEquals(keyVersion, doc.getKeyVersion());

        String testParams = "new-param";
        Timestamp newTimestamp = new Timestamp(System.currentTimeMillis());

        doc.setId(doc.getId() + testParams);
        doc.setName(doc.getName() + testParams);
        doc.setDescription(doc.getDescription() + testParams);
        doc.setTopic(doc.getTopic() + testParams);
        doc.setPushEndpoint(doc.getPushEndpoint() + testParams);
        doc.setCreatedBy(doc.getCreatedBy() + testParams);
        doc.setCreatedOnEpoch(newTimestamp);
        doc.setNotificationId(doc.getNotificationId() + testParams);
        doc.setDataPartitionId(doc.getDataPartitionId() + testParams);
        doc.setKeyName(doc.getKeyName() + testParams);
        doc.setKeyVersion(doc.getKeyVersion() + testParams);

        assertEquals(id + testParams, doc.getId());
        assertEquals(name + testParams, doc.getName());
        assertEquals(description + testParams, doc.getDescription());
        assertEquals(topic + testParams, doc.getTopic());
        assertEquals(pushEndpoint + testParams, doc.getPushEndpoint());
        assertEquals(createdBy + testParams, doc.getCreatedBy());
        assertEquals(newTimestamp, doc.getCreatedOnEpoch());
        assertEquals(notificationId + testParams, doc.getNotificationId());
        assertEquals(dataPartitionId + testParams, doc.getDataPartitionId());
        assertEquals(keyName + testParams, doc.getKeyName());
        assertEquals(keyVersion + testParams, doc.getKeyVersion());

    }

    @Test
    public void shouldCreateActionDocWithNoArgsConstructor() {
        SubscriptionDoc doc = new SubscriptionDoc();
        assertNotNull(doc);
    }
}
