/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.provider.gcp.subscriber;

import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.register.subscriber.model.Secret;
import org.opengroup.osdu.register.subscriber.model.Subscription;
import org.opengroup.osdu.register.provider.interfaces.subscriber.ISubscriptionRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public class SubscriptionRepository implements ISubscriptionRepository {

    @Autowired
    private IDatastoreAccess datastoreAccess;

    @Override
    public Subscription create(Subscription input) throws Exception {
        int existingSubscriptionsCount = datastoreAccess.getAll().size();
        // Due to the limit of google subscription per project, we are restricting the limit per tenant to 50
        // This already looks a difficult limit to reach, but need to keep a watch on this number.
        if (existingSubscriptionsCount == 50)
            throw new AppException(429, "Subscription quota reached",
                    "Number of subscription allowed have already reached to maximum");

        input = datastoreAccess.create(input);
        return input;
    }

    @Override
    public Subscription get(String id) {
        return datastoreAccess.get(id);
    }

    @Override
    public List<Subscription> query(String notificationId) {
        return datastoreAccess.query(notificationId);
    }

    @Override
    public boolean delete(String id) {
        return datastoreAccess.delete(id);
    }

    @Override
    public boolean patch(Subscription subscription, Secret secret) {
        return datastoreAccess.patch(subscription.getId(), secret);
    }

    @Override
    public List<Subscription> getAll() throws Exception {
        return datastoreAccess.getAll();
    }
}
